#
# spec file for package apparmor
#
# Copyright (c) 2017 SUSE LINUX GmbH, Nuernberg, Germany.
# Copyright (c) 2011-2017 Christian Boltz
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


# warning - confusing syntax ahead ;-)
# bcond_with means "disable"
# bcond_without means "enable"
%bcond_with tomcat
%bcond_without pam
%bcond_without apache
%bcond_without perl
%if 0%{?suse_version} > 0 && 0%{?suse_version} <= 1210
 # disable python and ruby bindings on openSUSE <= 12.1 to avoid problems with rb_sitearch and python_sitearch
 %bcond_with python
 %bcond_with python3
 %bcond_with ruby
%else
%if 0%{?suse_version} == 1220
 # swig for python3 is broken on 12.2 - probably http://sourceforge.net/p/swig/bugs/1257/ - build python2 bindings instead
 %bcond_without python
 %bcond_with python3
 %bcond_without ruby
%else
 %bcond_with python
 %bcond_without python3
 %bcond_without ruby
%endif
%endif

%define CATALINA_HOME /usr/share/tomcat6
#define APPARMOR_DOC_DIR /usr/share/doc/packages/apparmor-docs/
#define JNI_SO libJNIChangeHat.so
%define JAR_FILE changeHatValve.jar
%define apache_module_path %(/usr/sbin/apxs2 -q LIBEXECDIR)

Name:           apparmor
%if ! %{?distro:1}0
%if %{?suse_version:1}0
  %define distro suse
%endif
%if %{?fedora_version:1}0
  %define distro redhat
%endif
%endif
%if ! %{?distro:1}0
  %define distro suse
%endif
Version:        2.10.2
Release:        14.19
Summary:        AppArmor userlevel parser utility
License:        GPL-2.0+
Group:          Productivity/Networking/Security
Source0:        apparmor-%{version}.tar.gz
Source1:        apparmor-%{version}.tar.gz.asc
Source2:        %{name}.keyring

Source5:        update-trans.sh
Source6:        baselibs.conf
Source7:        apparmor-rpmlintrc
Source8:        apparmor.service
# enable caching of profiles (= massive performance speedup when loading profiles)
Patch1:         apparmor-enable-profile-cache.diff

# include autogenerated profile sniplet for samba shares (bnc#688040)
Patch2:         apparmor-samba-include-permissions-for-shares.diff

# split a long string in AppArmor.pm. Not accepted upstream because they want a solution without hardcoded width.
Patch3:         apparmor-utils-string-split

# fix regression in aa-unconfined netstat call (taken from upstream 2.10 branch r3380)
Patch4:         aa-unconfined-fix-netstat-call-2.10r3380.diff

# Ruby 2.0 mkmf prefixes everything with $(DESTDIR), bnc#822277, kkaempf@suse.de
Patch5:         ruby-2_0-mkmf-destdir.patch

# change multiline rules in abstractions to one line - needed because YaST still uses the perl module, which doesn't support multiline rules
# (bnc#900013, not for upstream)
Patch6:         apparmor-abstractions-no-multiline.diff

# bug 906858 - confine lessopen.sh (submitted upstream 2014-12-21)
Patch7:         apparmor-lessopen-profile.patch

# abstractions/base, abstractions/apache2-common and dovecot profile updates (taken from upstream 2.10 branch r3381..3384)
Patch8:         profile-updates-2.10r3381..3384.diff

Url:            https://launchpad.net/apparmor
PreReq:         sed
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
%if %{distro} == "suse"
PreReq:         %{insserv_prereq}
PreReq:         aaa_base
%endif
%define apparmor_bin_prefix /lib/apparmor
BuildRequires:  bison
BuildRequires:  flex
BuildRequires:  gcc-c++
BuildRequires:  latex2html
BuildRequires:  pcre-devel
BuildRequires:  pkg-config
BuildRequires:  python
BuildRequires:  perl(Locale::gettext)
%if 0%{?suse_version} > 1220
BuildRequires:  texlive-amsfonts
BuildRequires:  texlive-cm-super
%endif
BuildRequires:  texlive-latex
BuildRequires:  w3m

BuildRequires:  swig

%if %{with python}
BuildRequires:  python-devel
BuildRequires:  swig
%endif

%if %{with python3}
BuildRequires:  python3-devel
BuildRequires:  swig
%endif

%if %{with ruby}
BuildRequires:  ruby-devel
BuildRequires:  swig
%endif

%if %{with apache}
BuildRequires:  apache2-devel
%endif

%if %{with tomcat}
BuildRequires:  ant
BuildRequires:  java-devel >= 1.6.0
BuildRequires:  tomcat6
%endif

%package parser
Summary:        AppArmor userlevel parser utility
License:        GPL-2.0+
Group:          Productivity/Networking/Security
Obsoletes:      libimnxcert < %{version}
Obsoletes:      subdomain-leaf-cert < %{version}
Obsoletes:      subdomain-parser < %{version}
Obsoletes:      subdomain-parser-common < %{version}
Obsoletes:      subdomain-parser-demo < %{version}
Obsoletes:      subdomain_parser < %{version}
Provides:       libimnxcert = %{version}
Provides:       subdomain-leaf-cert = %{version}
Provides:       subdomain-parser = %{version}
Provides:       subdomain-parser-common = %{version}
Provides:       subdomain-parser-demo = %{version}
Provides:       subdomain_parser = %{version}
Provides:       apparmor-parser(CAP_SYSLOG)

# initscript needs /lib/lsb/init-functions from insserv/insserv-compat
Requires:       insserv

%if 0%{?suse_version} > 1320 || 0%{?suse_version} == 1315
BuildRequires:  systemd-rpm-macros
%{?systemd_requires}
%endif

%description parser
The AppArmor Parser is a userlevel program that is used to load in
program profiles to the AppArmor Security kernel module.

This package is part of a suite of tools that used to be named
SubDomain.

%package docs
Summary:        AppArmor Documentation package
License:        GPL-2.0+
Group:          Documentation/Other
BuildArch:      noarch

%description docs
This package contains documentation for AppArmor.

This package is part of a suite of tools that used to be named
SubDomain.

%if %{with apache}

%package -n apache2-mod_apparmor
Summary:        AppArmor module for apache2
License:        GPL-2.0+
Group:          Productivity/Security

%description -n apache2-mod_apparmor
apache2-modapparmor adds support to apache2 to provide AppArmor
confinement to individual cgi scripts handled by apache modules like
mod_php and mod_perl.

This package is part of a suite of tools that used to be named
SubDomain.

The documentation is in the apparmor-admin_en package.

%endif

%package -n libapparmor1
Summary:        Utility library for AppArmor
License:        LGPL-2.1+
Group:          Development/Libraries/C and C++
%ifarch ppc64
Obsoletes:      libapparmor-64bit < %{version}
Provides:       libapparmor-64bit = %{version}
%endif
Provides:       libapparmor = %{version}
#Provides:       libimmunix = %{version}
Obsoletes:      libapparmor < %{version}
#Obsoletes:      libimmunix < %{version}

%description -n libapparmor1
This package provides the libapparmor library, which contains the
change_hat(2) symbol, used for sub-process confinement by AppArmor, as
well as functions to parse AppArmor log messages.

%package -n libapparmor-devel
Summary:        Development headers and libraries for libapparmor
License:        LGPL-2.1+
Group:          Development/Libraries/C and C++
Requires:       libapparmor1 = %{version}
Provides:       libapparmor:/usr/include/sys/apparmor.h

%description -n libapparmor-devel
These libraries are needed for developing software that makes use of the
AppArmor API.

%if %{with perl}

%package -n perl-apparmor
Summary:        Perl interface for libapparmor functions
License:        GPL-2.0 and LGPL-2.1+
Group:          Development/Libraries/Perl
Requires:       libapparmor1 = %{version}
Requires:       perl = %{perl_version}
Requires:       perl(DBD::SQLite)
Requires:       perl(Locale::gettext)
Requires:       perl(RPC::XML)
Requires:       perl(RPC::XML)
Requires:       perl(Term::ReadKey)
Requires:       perl(Term::ReadKey)
Provides:       perl-libapparmor = %{version}
Obsoletes:      perl-libapparmor < 2.5

%description -n perl-apparmor
This package provides the perl interface to AppArmor. It is used for perl
applications interfacing with AppArmor, including the AppArmor utilities.

%endif

%if %{with python}

%package -n python-apparmor
Summary:        Python 2 interface for libapparmor functions
License:        GPL-2.0 and LGPL-2.1+
Group:          Development/Libraries/Python
BuildRequires:  python
Requires:       libapparmor1 = %{version}
Requires:       python = %{python_version}
Provides:       python-libapparmor = %{version}
Obsoletes:      python-libapparmor < 2.5

%description -n python-apparmor
This package provides the python interface to AppArmor. It is used for python
applications interfacing with AppArmor.

%endif

%if %{with python3}

%package -n python3-apparmor
Summary:        Python 3 interface for libapparmor functions
License:        GPL-2.0 and LGPL-2.1+
Group:          Development/Libraries/Python
Requires:       libapparmor1 = %{version}
Requires:       python3 = %{py3_ver}
Requires:       python(abi) = %{py3_ver}
Provides:       python-libapparmor = %{version}

%description -n python3-apparmor
This package provides the python interface to AppArmor. It is used for python
applications interfacing with AppArmor.

%endif

%if %{with ruby}

%package -n ruby-apparmor
Summary:        Ruby interface for libapparmor functions
License:        GPL-2.0 and LGPL-2.1+
Group:          Development/Languages/Ruby
Requires:       libapparmor1 = %{version}
Requires:       ruby = %(rpm -q --qf '%%{version}' ruby)
Provides:       ruby-libapparmor = %{version}
Obsoletes:      ruby-libapparmor < 2.5

%description -n ruby-apparmor
This package provides the ruby interface to AppArmor. It is used for ruby
applications interfacing with AppArmor.

%endif

%package abstractions
Summary:        AppArmor abstractions and directory structure
License:        GPL-2.0 and LGPL-2.1+
Group:          Productivity/Security
Requires:       apparmor-parser(CAP_SYSLOG)
BuildArch:      noarch

%description abstractions
AppArmor abstractions (common parts used in various profiles) and
the /etc/apparmor.d/ directory structure.

AppArmor is a file and network mandatory access control mechanism.
AppArmor confines processes to the resources allowed by the systems
administrator and can constrain the scope of potential security
vulnerabilities.

This package is part of a suite of tools that used to be named
SubDomain.

%package profiles
Summary:        AppArmor profiles that are loaded into the apparmor kernel module
License:        GPL-2.0 and LGPL-2.1+
Group:          Productivity/Security
Requires:       apparmor-abstractions >= %{version}
Requires:       apparmor-parser(CAP_SYSLOG)
Obsoletes:      subdomain-profiles < %{version}
Provides:       subdomain-profiles = %{version}
BuildArch:      noarch

%description profiles
Base profiles. AppArmor is a file and network mandatory access control
mechanism. AppArmor confines processes to the resources allowed by the
systems administrator and can constrain the scope of potential security
vulnerabilities.

This package is part of a suite of tools that used to be named
SubDomain.

%package utils
Summary:        AppArmor User-Level Utilities Useful for Creating AppArmor Profiles
License:        GPL-2.0 and LGPL-2.1+
Group:          Productivity/Security
Requires:       libapparmor1 = %{version}
# some of the tools are still perl-based (aa-decode, aa-exec and aa-notify)
Requires:       perl = %{perl_version}
Requires:       perl-apparmor = %{version}
%if %{with python3}
Requires:       python3-apparmor = %{version}
Requires:       python3-base
%else
Requires:       python-apparmor = %{version}
Requires:       python-base
%endif
# aa-unconfined needs netstat
# Leap 42.1 and 42.1 still use the old "net-tools" name, so no == 1315 here even if 42.x is newer than 13.2
%if 0%{?suse_version} > 1320
Recommends:     net-tools-deprecated
%else
Recommends:     net-tools
%endif
# aa-notify -p needs notify-send
Recommends:     libnotify-tools
BuildArch:      noarch

%description utils
This package provides the aa-logprof, aa-genprof, aa-autodep,
aa-enforce, and aa-complain tools to assist with profile authoring.
Besides it provides the aa-unconfined server information tool.
It is part of a suite of tools that used to be named SubDomain.

%if %{with tomcat}

%package -n tomcat_apparmor
Summary:        Tomcat 6 plugin for AppArmor change_hat
License:        GPL-2.0 and LGPL-2.1+
Group:          System/Libraries
Requires:       libapparmor1 = %{version}
Requires:       tomcat6

%description -n tomcat_apparmor
tomcat_apparmor - is a plugin for Apache Tomcat version 6 that
provides support for AppArmor change_hat for creating AppArmor
containers that are bound to discrete elements of processing within the
Tomcat servlet container. The AppArmor containers, or "hats", can be
created for individual URL processing or per servlet.

%endif

%if %{with pam}

%package -n pam_apparmor
Summary:        PAM module for AppArmor change_hat
License:        GPL-2.0 and LGPL-2.1+
Group:          Productivity/Security
BuildRequires:  pam-devel
PreReq:         pam
PreReq:         pam-config
Requires:       pam
Requires:       pam-config

%description -n pam_apparmor
The pam_apparmor module provides the means for any PAM applications
that call pam_open_session() to automatically perform an AppArmor
change_hat operation in order to switch to a user-specific security
policy.

%endif

%description
The AppArmor Parser is a userlevel program that is used to load in
program profiles to the AppArmor Security kernel module.

This package is part of a suite of tools that used to be named
SubDomain.

%lang_package -n apparmor-utils
%lang_package -n apparmor-parser

%prep
%setup -q
%patch1 -p1
%patch2
%patch3 -p1
%patch4

# Ruby 2.0 mkmf prefixes every path with $(DESTDIR)
%if 0%{?suse_version} > 1230
%patch5 -p1
%endif

%patch6
%patch7 -p1
%patch8
# patch8 (upstream-changes-2.10-r3385..3390.diff) fails to create empty files, do it manually
touch libraries/libapparmor/testsuite/test_multi/unconfined-change_hat.err

# search for left-over multiline rules
test -z "$(grep -r '^\s*\(unix\|dbus\)[^,]\(([^)]*)\)*[^,]*$' profiles/apparmor.d/)"

%build
echo _libdir: %{_libdir}  ruby: %{rb_sitearch}  python: %{python3_sitearch} # test if _libdir breaks it or if it's broken by default on <= 12.1

export SUSE_ASNEEDED=0
# re-define _libdir to /lib or /lib64
%define _libdir /%{_lib}

echo new _libdir: %{_libdir}  ruby: %{rb_sitearch}  python: %{python3_sitearch} # test if _libdir breaks it or if it's broken by default on <= 12.1

%if %{with python3}
export PYTHON=/usr/bin/python3
%endif

# libapparmor:
(
  cd ./libraries/libapparmor
  %configure \
%if %{with perl}
  --with-perl \
%endif
%if %{with python}%{with python3}
  --with-python \
%else
  --without-python \
%endif
%if %{with ruby}
  --with-ruby \
%else
  --without-ruby \
%endif

  make
)

# Utilities:
make -C utils

# deprecated/utils (perl modules still needed by YaST)
%if %{with perl}
make -C deprecated/utils
%endif

# parser:
make -C parser V=1
# techdoc.txt depends on techdoc.pdf and techdoc/index.html, so make techdoc.txt should be enough
make -C parser V=1 techdoc.txt

# Apache mod_apparmor:
%if %{with apache}
  make -C changehat/mod_apparmor
%endif

# PAM AppArmor:
%if %{with pam}
  make -C changehat/pam_apparmor
%endif

# Profiles:
make -C profiles

##configure --disable-static --with-pic \
#--with-perl \
%if %{with tomcat}
  make -C changehat/tomcat_apparmor/tomcat_5_5 CATALINA_HOME=%{CATALINA_HOME}
%endif

%check
%if %{with python3}
export PYTHON=/usr/bin/python3
export PYTHON_VERSIONS=python3
%endif

make check -C libraries/libapparmor
make check -C parser
# profiles make check fails for the utils (libapparmor PYTHONPATH issues), therefore only do parser-based checks
# also, check-parser breaks if using 'make -C' (but works if cd'ing into the directory)
(cd profiles && make check-parser)
# utils make check fails if profiles don't exist in /etc/apparmor.d/
# make check -C utils

%install

%if %{with python3}
export PYTHON=/usr/bin/python3
%endif

# libapparmor
# override pkgconfigdir for now - TODO: don't redefine libdir when packaging AppArmor 3.0
%makeinstall -C libraries/libapparmor pkgconfigdir=/usr/%{_lib}/pkgconfig/
# create symlink for old change_hat(2) manpage
( cd %{buildroot}/%{_mandir}/man2/ && ln -s aa_change_hat.2 change_hat.2 )

# utilities
%makeinstall -C utils
test ! -x %{buildroot}/%{_bindir}/aa-easyprof && chmod +x %{buildroot}/%{_bindir}/aa-easyprof # https://bugs.launchpad.net/apparmor/+bug/1366568
mkdir -p %{buildroot}%{_localstatedir}/log/apparmor
%if %{with python3}
    # enforce usage of python3
    for file in %{buildroot}/%{_sbindir}/aa-* ; do
        sed -i '1s,^#! /usr/bin/env python$,#! /usr/bin/env python3,' "$file"
    done
%endif

# deprecated/utils (perl modules still needed by YaST)
%if %{with perl}
%makeinstall -C deprecated/utils
%endif

%makeinstall -C profiles

%makeinstall -C parser
# default cache dir is /etc/apparmor.d/cache - not the best location.
# Use /var/lib/apparmor/cache and make /etc/apparmor.d/cache a symlink to it
mkdir -p %{buildroot}%{_localstatedir}/lib/apparmor/cache
( cd %{buildroot}/%{_sysconfdir}/apparmor.d/ && ln -s ../../%{_localstatedir}/lib/apparmor/cache cache )

%if %{with apache}
  %makeinstall -C changehat/mod_apparmor
%endif

%if %{with pam}
  %makeinstall -C changehat/pam_apparmor SECDIR=%{buildroot}%{_libdir}/security
%endif

%if %{with tomcat}
  mkdir -p %{buildroot}/%{CATALINA_HOME}
  %makeinstall -C changehat/tomcat_apparmor/tomcat_5_5 CATALINA_HOME=%{buildroot}/%{CATALINA_HOME}
%endif

find %{buildroot} -name .packlist -exec rm -f {} \;
find %{buildroot} -name perllocal.pod -exec rm -f {} \;

# Re-create the links to the old names, but only for tools and manpages that had it for historic reasons[tm].
# Tools and manpages added in >= 2.9 won't get symlinks without aa- prefix
for file in %{buildroot}%{_prefix}/{sbin,share/man/man[0-9]}/aa-*; do
    d=$(dirname $file)
    f=$(basename $file)
    case "${f#aa-}" in
        audit    | autodep    | complain    | decode | disable                  | enforce    | exec    | genprof    | logprof    | notify   | status   | unconfined  | \
        audit.8* | autodep.8* | complain.8*          | disable.8* | easyprof.8* | enforce.8* | exec.8* | genprof.8* | logprof.8* | notify.8 | status.8 | unconfined.8* )
            if [ "${f#aa-}" != "$f" ]; then
                ln -s $f $d/${f#aa-}
            fi
        ;;
    esac
done

mv -f %{buildroot}%{_mandir}/man8/{status.8,apparmor_status.8}
mv -f %{buildroot}%{_mandir}/man8/{notify.8,apparmor_notify.8}
rm -f %{buildroot}%{_mandir}/man8/decode.8

for pkg in apparmor-utils apparmor-parser; do
    %find_lang $pkg
done

# remove *.la files
rm -fv %{buildroot}%{_libdir}/libapparmor.la 

%if 0%{?suse_version} > 1320 || 0%{?suse_version} == 1315
install -D -m0644 %{S:8} %{buildroot}%{_unitdir}/apparmor.service
%endif

echo -------------------------------------------------------------------
#find -ls
echo -------------------------------------------------------------------
#find %{buildroot} -ls
echo -------------------------------------------------------------------

%files docs
%defattr(-,root,root)
%doc parser/*.[1-9].html
%doc utils/vim/apparmor.vim.5.html
%doc common/apparmor.css
%doc parser/techdoc.pdf parser/techdoc/techdoc.html parser/techdoc/techdoc.css parser/techdoc.txt
# apparmor.vim is included in the vim package. Ideally it should be in a -devel package, but that's overmuch for one file
%dir %{_datadir}/apparmor
%{_datadir}/apparmor/apparmor.vim

%files parser
%defattr(-,root,root)
%doc parser/README parser/COPYING.GPL
/sbin/apparmor_parser
%dir %attr(-, root, root) %{_sysconfdir}/apparmor
%dir %{_sysconfdir}/apparmor.d
%{_sysconfdir}/apparmor.d/cache
%if %{distro} == "suse"
  /sbin/rcsubdomain
  /sbin/rcapparmor
  %{_sysconfdir}/init.d/boot.apparmor
%else
  %{_sysconfdir}/init.d/apparmor
%endif
%if 0%{?suse_version} > 1320 || 0%{?suse_version} == 1315
%{_unitdir}/apparmor.service
%endif
%config(noreplace) %{_sysconfdir}/apparmor/subdomain.conf
%config(noreplace) %{_sysconfdir}/apparmor/parser.conf
%{_localstatedir}/lib/apparmor
%dir %attr(-, root, root) %{apparmor_bin_prefix}
%{apparmor_bin_prefix}/rc.apparmor.functions
%doc %{_mandir}/man5/apparmor.d.5.gz
%doc %{_mandir}/man5/apparmor.vim.5.gz
%doc %{_mandir}/man5/subdomain.conf.5.gz
%doc %{_mandir}/man7/apparmor.7.gz
%doc %{_mandir}/man8/apparmor_parser.8.gz

%pre parser
if [ -f %{_sysconfdir}/init.d/subdomain ] ; then
  chkconfig --del subdomain
fi
%if 0%{?suse_version} > 1320 || 0%{?suse_version} == 1315
# service existed before, but it had been switched to a bad state (boo#1017260). Force service_add_post to run preset.
if [ $1 -gt 1 ] ; then
    for file in /etc/init.d/boot.d/*boot.apparmor ; do
        test -L "$file" || continue
        echo -n "" >/run/rpm-%{name}-update-apparmor.service-new-in-upgrade
    done
fi
%service_add_pre apparmor.service
%endif

%files parser-lang -f apparmor-parser.lang

%files -n libapparmor1
%defattr(-,root,root)
%{_libdir}/libapparmor.so.*

%files -n libapparmor-devel
%defattr(-,root,root)
%{_libdir}/libapparmor.a
%{_libdir}/libapparmor.so
/usr/%{_lib}/pkgconfig/libapparmor.pc
%doc %{_mandir}/man2/aa_change_hat.2.gz
%doc %{_mandir}/man2/change_hat.2.gz
%doc %{_mandir}/man2/aa_find_mountpoint.2.gz
%doc %{_mandir}/man2/aa_getcon.2.gz
%doc %{_mandir}/man2/aa_query_label.2.gz
%doc %{_mandir}/man3/aa_features.3.gz
%doc %{_mandir}/man3/aa_kernel_interface.3.gz
%doc %{_mandir}/man3/aa_policy_cache.3.gz
%doc %{_mandir}/man3/aa_splitcon.3.gz
%dir %{_includedir}/aalogparse
%{_includedir}/sys/apparmor.h
%{_includedir}/sys/apparmor_private.h
%{_includedir}/aalogparse/*

%files abstractions
%defattr(644,root,root,755)
%dir %{_sysconfdir}/apparmor.d/
%dir %{_sysconfdir}/apparmor.d/abstractions
%config(noreplace) %{_sysconfdir}/apparmor.d/abstractions/*
%dir %{_sysconfdir}/apparmor.d/disable
%dir %{_sysconfdir}/apparmor.d/local
%dir %{_sysconfdir}/apparmor.d/tunables
%config(noreplace) %{_sysconfdir}/apparmor.d/tunables/*

%files profiles
%defattr(644,root,root,755)
%dir %{_sysconfdir}/apparmor.d/apache2.d
%config(noreplace) %{_sysconfdir}/apparmor.d/apache2.d/phpsysinfo
%config(noreplace) %{_sysconfdir}/apparmor.d/bin.*
%config(noreplace) %{_sysconfdir}/apparmor.d/sbin.*
%config(noreplace) %{_sysconfdir}/apparmor.d/usr.*
%config(noreplace) %{_sysconfdir}/apparmor.d/local/*
/usr/share/apparmor/extra-profiles/

%files utils
%defattr(-,root,root)
%dir %{_sysconfdir}/apparmor
%config(noreplace) %{_sysconfdir}/apparmor/easyprof.conf
%config(noreplace) %{_sysconfdir}/apparmor/logprof.conf
%config(noreplace) %{_sysconfdir}/apparmor/notify.conf
%config(noreplace) %{_sysconfdir}/apparmor/severity.db
%{_sbindir}/aa-*
%{_sbindir}/apparmor_status
%{_sbindir}/audit
%{_sbindir}/autodep
%{_sbindir}/complain
%{_sbindir}/decode
%{_sbindir}/disable
%{_sbindir}/enforce
%{_sbindir}/exec
%{_sbindir}/genprof
%{_sbindir}/logprof
%{_sbindir}/notify
%{_sbindir}/status
%{_sbindir}/unconfined
%{_bindir}/aa-easyprof
%dir %{_datadir}/apparmor
%{_datadir}/apparmor/easyprof/
%dir %{_localstatedir}/log/apparmor
%doc %{_mandir}/man2/aa_change_profile.2.gz
%doc %{_mandir}/man5/logprof.conf.5.gz
%doc %{_mandir}/man8/apparmor_notify.8.gz
%doc %{_mandir}/man8/aa-*.gz
%doc %{_mandir}/man8/apparmor_status.8.gz
%doc %{_mandir}/man8/audit.8.gz
%doc %{_mandir}/man8/autodep.8.gz
%doc %{_mandir}/man8/complain.8.gz
%doc %{_mandir}/man8/disable.8.gz
%doc %{_mandir}/man8/easyprof.8.gz
%doc %{_mandir}/man8/enforce.8.gz
%doc %{_mandir}/man8/exec.8.gz
%doc %{_mandir}/man8/genprof.8.gz
%doc %{_mandir}/man8/logprof.8.gz
%doc %{_mandir}/man8/unconfined.8.gz
%doc utils/*.[0-9].html
%doc common/apparmor.css

%files utils-lang -f apparmor-utils.lang

%if %{with perl}
%files -n perl-apparmor
%defattr(-,root,root)
%{perl_vendorlib}/Immunix
%{perl_vendorarch}/auto/LibAppArmor/
%{perl_vendorarch}/LibAppArmor.pm
%endif

%if %{with python}

%files -n python-apparmor
%defattr(-,root,root)
%{python_sitearch}/LibAppArmor-%{version}-py%{python_version}.egg-info
%dir %{python_sitearch}/LibAppArmor
%{python_sitearch}/LibAppArmor/_LibAppArmor.so
%{python_sitearch}/LibAppArmor/__init__.py
%{python_sitearch}/LibAppArmor/__init__.pyc
%{python_sitelib}/apparmor/
%{python_sitelib}/apparmor-%{version}-py%{python_version}.egg-info
%endif

%if %{with python3}

%files -n python3-apparmor
%defattr(-,root,root)
%{python3_sitearch}/LibAppArmor-%{version}-py*.egg-info
%dir %{python3_sitearch}/LibAppArmor
%dir %{python3_sitearch}/LibAppArmor/__pycache__
%{python3_sitearch}/LibAppArmor/_LibAppArmor.cpython-*.so
%{python3_sitearch}/LibAppArmor/__pycache__/__init__.cpython-*.pyc
%{python3_sitearch}/LibAppArmor/__pycache__/LibAppArmor.cpython-*.pyc
%{python3_sitearch}/LibAppArmor/__init__.py
%{python3_sitearch}/LibAppArmor/LibAppArmor.py
%{python3_sitelib}/apparmor/
%{python3_sitelib}/apparmor-%{version}-py*.egg-info
%endif

%if %{with ruby}

%files -n ruby-apparmor
%defattr(-,root,root)
%{rb_sitearchdir}/LibAppArmor.so
%endif

%if %{with pam}

%files -n pam_apparmor
%defattr(444,root,root,755)
%attr(555,root,root) %{_libdir}/security/pam_apparmor.so
%endif

%if %{with tomcat}

%files -n tomcat_apparmor
%defattr(-,root,root)
%{CATALINA_HOME}/lib/%{JAR_FILE}
%{_libdir}/libJNI*
%doc %attr(0644,root,root) changehat/tomcat_apparmor/tomcat_5_5/README.tomcat_apparmor
%endif

%if %{with apache}

%files -n apache2-mod_apparmor
%defattr(-,root,root)
%{apache_module_path}/mod_apparmor.so
%doc %{_mandir}/man8/mod_apparmor.8.gz
%endif

%post parser
%if %{distro} == "suse"
  # SUSE uses insserv
  # For package renaming from subdomain -> apparmor
  # we check the existence of the AppArmor 1.1 and
  # AppArmor 1.2 based init script to help determine
  # whether  we are upgrading
  SUBDOMAIN_PARSER_INSTALLED="no"
  if test -e %{_sysconfdir}/init.d/boot.subdomain -o -e %{_sysconfdir}/init.d/subdomain; then
    SUBDOMAIN_PARSER_INSTALLED="yes"
  fi
  if  test "$1" = 1  -a $SUBDOMAIN_PARSER_INSTALLED = "no"; then
    %{insserv_force_if_yast boot.apparmor}
  elif test -e %{_sysconfdir}/rc.d/boot.d/S??boot.subdomain  -o \
            -e %{_sysconfdir}/rc.d/boot.d/S??boot.apparmor  -o \
            -e %{_sysconfdir}/rc.d/rc3.d/S??subdomain ; then
    %{insserv_force_if_yast boot.apparmor}
  else
    %{fillup_and_insserv -f boot.apparmor}
  fi
%endif
%if %{distro} == "redhat" || %{distro} == "rhel4"
  chkconfig --add apparmor
%endif
%if %{distro} == "slackware"
  if grep -qs "# BEGIN rc.subdomain INSERTION" %{_sysconfdir}/rc.d/rc.M ; then true ; else
    %{apparmor_bin_prefix}/install/frob_slack_rc --init
  fi
  if grep -qs "# BEGIN rc.subdomain INSERTION" %{_sysconfdir}/rc.d/rc.K ; then true ; else
    %{apparmor_bin_prefix}/install/frob_slack_rc --shutdown
  fi
%endif

%if 0%{?suse_version} > 1320 || 0%{?suse_version} == 1315
%service_add_post apparmor.service
%endif

%preun parser
if [ "$1" = 0 ] ; then
%if %{distro} == "suse"
  %{stop_on_removal boot.apparmor}
%endif
%if %{distro} == "redhat" || %{distro} == "rhel4"
  chkconfig --del apparmor
%endif
fi

%if 0%{?suse_version} > 1320 || 0%{?suse_version} == 1315
%service_del_preun apparmor.service
%endif

%postun parser
%if %{distro} == "suse"
  #restart_on_update boot.apparmor - but non-broken (bnc#853019)
  test -n "$FIRST_ARG" || FIRST_ARG=$1
  if test "$FIRST_ARG" -ge 1 ; then
    if test "$YAST_IS_RUNNING" != "instsys" -a "$DISABLE_RESTART_ON_UPDATE" != yes ; then
      test -x /bin/systemctl && /bin/systemctl daemon-reload >/dev/null 2>&1 || :
      /etc/init.d/boot.apparmor status >/dev/null && /etc/init.d/boot.apparmor reload || :
    fi
  fi

  %{insserv_cleanup} || true
%endif

%if 0%{?suse_version} > 1320 || 0%{?suse_version} == 1315
# don't call try-restart, see bnc#853019
export DISABLE_RESTART_ON_UPDATE="yes"
%service_del_postun apparmor.service
%endif

%post abstractions
%if %{distro} == "suse"
  #restart_on_update boot.apparmor - but non-broken (bnc#853019)
  # (copy&paste from parser postun script)
  test -n "$FIRST_ARG" || FIRST_ARG=$1
  if test "$FIRST_ARG" -ge 1 ; then
    if test "$YAST_IS_RUNNING" != "instsys" -a "$DISABLE_RESTART_ON_UPDATE" != yes ; then
      test -x /bin/systemctl && /bin/systemctl daemon-reload >/dev/null 2>&1 || :
      /etc/init.d/boot.apparmor status >/dev/null && /etc/init.d/boot.apparmor reload || :
    fi
  fi
%endif

%post profiles
%if %{distro} == "suse"
  # workaround for bnc#904620#c8 / lp#1392042
  rm -f /var/cache/apparmor/*
  #restart_on_update boot.apparmor - but non-broken (bnc#853019)
  # (copy&paste from parser postun script)
  test -n "$FIRST_ARG" || FIRST_ARG=$1
  if test "$FIRST_ARG" -ge 1 ; then
    if test "$YAST_IS_RUNNING" != "instsys" -a "$DISABLE_RESTART_ON_UPDATE" != yes ; then
      test -x /bin/systemctl && /bin/systemctl daemon-reload >/dev/null 2>&1 || :
      /etc/init.d/boot.apparmor status >/dev/null && /etc/init.d/boot.apparmor reload || :
    fi
  fi
%endif

%post -n libapparmor1 -p /sbin/ldconfig

%postun -n libapparmor1 -p /sbin/ldconfig

%if %{with tomcat}

%post -n tomcat_apparmor -p /sbin/ldconfig

%postun -n tomcat_apparmor -p /sbin/ldconfig
%endif

%if %{with pam}

%post -n pam_apparmor
pam-config -a --apparmor
pam-config --update

%postun -n pam_apparmor
pam-config -d --apparmor
pam-config --update
%endif

%changelog
* Sun Mar 26 2017 suse-beta@cboltz.de
- add upstream-changes-2.10-r3385..3390.diff:
  - preserve unknown profiles when reloading apparmor.service
    (CVE-2017-6507, lp#1668892, boo#1029696)
  - add aa-remove-unknown utility to unload unknown profiles (lp#1668892)
  - remove deprecated re.LOCALE flag in Python UI as it was dropped from Python
    3.6 (lp#1661766)
  - fix a crash in aa-logprof on specific change_hat events
- migration to apparmor.service turned out to accidently disable AppArmor.
  Add a workaround to fix this (boo#1017260 starting at #c7)
  Note: This will re-enable AppArmor if it was disabled by the last update.
  You'll need to "rcapparmor reload" to actually load the profiles, and then
  check aa-status for programs that need to be restarted to apply the profiles.
- add var.mount dependeny to apparmor.service (boo#1016259#c34)
* Wed Feb  1 2017 suse-beta@cboltz.de
- Recommend net-tools instead of net-tools-deprecated for 42.x (boo#1022963)
* Mon Jan 30 2017 suse-beta@cboltz.de
- add profile-updates-2.10r3381..3384.diff with updates for
  abstractions/base, abstractions/apache2-common and dovecot profiles
* Tue Jan 24 2017 suse-beta@cboltz.de
- package apparmor.service also in Leap where it was missing thanks to a
  wrong/outdated if statement (boo#1017260)
  Note: If you manually disabled AppArmor, this change will re-enable it.
* Tue Jan 24 2017 suse-beta@cboltz.de
- change /etc/apparmor.d/cache symlink to /var/lib/apparmor/cache/.
  This is part of the root partition (at least with default partitioning)
  and should be available earlier than /var/cache/apparmor/
  (boo#1015249, boo#980081, bsc#1016259)
- add dependency on var-lib.mount to apparmor.service as safety net
* Tue Jan 10 2017 suse-beta@cboltz.de
- update to AppArmor 2.10.2 maintenance release
  - lots of bugfixes and profile updates (including boo#1000201,
    boo#1009964, boo#1014463)
  - see http://wiki.apparmor.net/index.php/ReleaseNotes_2_10_2 for details
- add aa-unconfined-fix-netstat-call-2.10r3380.diff to fix a regression
  in aa-unconfined
- drop upstream(ed) patches:
  - changes-since-2.10.1--r3326..3346.diff
  - changes-since-2.10.1--r3347..3353.diff
  - libapparmor-fix-import-path.diff (upstream fix is slightly different)
  - nscd-var-lib.diff
- refresh apparmor-abstractions-no-multiline.diff
* Sun Oct 23 2016 suse-beta@cboltz.de
- add nscd-var-lib.diff to allow /var/lib/nscd/ in the nscd profile and
  abstractions/nameservice (path changed in latest nscd in Tumbleweed)
* Thu Oct 13 2016 suse-beta@cboltz.de
- add changes-since-2.10.1--r3347..3353.diff with upstream changes and
  fixes in the 2.10 branch, including
  - allow writing *.qf files (for disk-based buffering) in syslog-ng profile
  - add several permissions to the dovecot profiles (deb#835826)
  - add a missing path in the traceroute profile
* Fri Aug 26 2016 suse-beta@cboltz.de
- add changes-since-2.10.1--r3326..3346.diff with upstream changes and
  fixes since the 2.10.1 release, including
  - allow dac_override in winbindd profile (boo#990006#c5)
  - allow mr for /usr/lib*/ldb/*.so in samba abstractions (needed since
    Samba 4.4.x, boo#990006)
  - abstractions/nameservice: also support ConnMan-managed resolv.conf
  - let aa-genprof ask about profiles in extra dir (again)
  - fix aa-logprof "add hat" endless loop (lp#1538306)
  - honor 'chown' file events in logparser.py
  - ignore log file events with a request mask of 'send' or 'receive'
    because they are actually network events (lp#1577051, lp#1582374)
  - accept hostname with dots when parsing logs (lp#1453300 comments #1 and #2)
- fix python LibAppArmor import failures with swig > 3.0.8 (boo#987607)
  (libapparmor-fix-import-path.diff)
- refresh apparmor-abstractions-no-multiline.diff
- drop upstreamed profiles-ping-inet6-r3449.diff
- add %%check section - runs libapparmor (including swig bindings),
  parser and profiles tests
- add BuildRequires: perl(Locale::gettext) - needed for parser tests
* Tue May 24 2016 suse-beta@cboltz.de
- add profiles-ping-inet6-r3449.diff - latest ping also does IPv6 (boo#980596)
* Fri Apr 22 2016 suse-beta@cboltz.de
- update to AppArmor 2.10.1 (2.10 branch r3326):
  - fix incorrect output of child profile names (apparmor_parser -N) which
    caused 'rcapparmor reload' to remove child profiles and hats (lp#1551950)
  - fix a crash in aa-logprof / logparser.py for change_hat log events
    (lp#1523297) and log events that look like file events, but aren't
    (lp#1540562, lp#1525119, lp#1466812)
  - write unix rules when saving a profile (lp#1522938, boo#954104#c3)
  - several fixes for variable handling in aa-logprof
  - map c (create) log events to w instead of a
  - add python to the "no Px rule" list in logprof.conf
  - let aa-logprof check for duplicate profiles
  - let aa-status work without the apparmor.fail python module (boo#971917,
    lp#1480492)
  - add permissions in several profiles (including boo#948584, boo#948753,
    boo#954959, boo#954958, boo#971790, boo#964971, boo#921098, boo#923201 and
    boo#921098#c15).
  - and many more fixes, see the full changelog at
    http://wiki.apparmor.net/index.php/ReleaseNotes_2_10_1
- drop upstream(ed) patches:
  - fix-initscript-aa_log_end_msg.diff
  - syslog-ng-profile-boo948584.diff
  - upstream-profile-updates-r3205-3241.diff
- refresh patches:
  - apparmor-abstractions-no-multiline.diff
  - apparmor-samba-include-permissions-for-shares.diff
- drop libapparmor autogen.sh call (broke the build) and remove libtool BR
* Wed Oct  7 2015 opensuse@cboltz.de
- add syslog-ng-profile-boo948584.diff - add several permissions needed
  by latest syslog-ng (boo#948584, boo#948753)
- add upstream-profile-updates-r3205-3241.diff with several profile updates:
  - add /usr/share/locale-bundle/** to abstractions/base
  - allow dnsmask to use /bin/sh (boo#940749) and /bin/dash
  - allow dovecot imap to read /run/dovecot/mounts
  - allow avahi-daemon to write to /run/systemd/notify
  - allow ntpd to read $PATH directory listings (boo#945592, boo#948752)
  - update dhclient profile
  - allow skype to read @{PROC}/@{pid}/net/dev (boo#939568)
  - and some other small updates
- drop upstreamed apparmor-winbindd-r3213.diff (included in the
  upstream-profile-updates patch)
* Sun Sep 13 2015 opensuse@cboltz.de
- netstat moved to net-tools-deprecated in Tumbleweed (boo#944904)
* Thu Jul 30 2015 opensuse@cboltz.de
- add apparmor-winbindd-r3213.diff - add missing k permissions for
  /etc/samba/smbd.tmp/msg/* in winbindd profile (boo#921098 #c15..19)
* Thu Jul 23 2015 opensuse@cboltz.de
- add fix-initscript-aa_log_end_msg.diff - fixes ugly initscript
  output (boo#862170)
* Thu Jul 16 2015 opensuse@cboltz.de
- update to AppArmor 2.10 (trunk r3205)
  - profile names can now contain variables
  - improved profile compile time in apparmor_parser
  - lots of improvements, refactoring and bugfixes in the aa-* tools
  - new apis for managing and loading profile caches into the kernel in
    libapparmor
  - lots of profile updates
  - see http://wiki.apparmor.net/index.php/ReleaseNotes_2_10 for the
    complete changelog with more details
- add new apparmor_private.h and the aa_query_label(2), aa_features(3),
  aa_kernel_interface(3), aa_policy_cache(3), aa_splitcon(3) manpages
  to libapparmor-devel
- drop apparmor-2.5.1-edirectory-profile patch - it's most probably
  no longer needed (see boo#621394 for details)
- drop upstreamed samba-4.2-profiles.diff
- refresh apparmor-samba-include-permissions-for-shares.diff
* Mon Jun 15 2015 opensuse@cboltz.de
- systemd-rpm-macros and %%systemd_requires were at the wrong place,
  move them to the parser package (boo#931792)
* Fri Apr 24 2015 opensuse@cboltz.de
- update to AppArmor 2.9.2 (2.9 branch r2911)
  - lots of bugfixes in the parser and the aa-* tools (including
    boo#918787)
  - update dovecot and dnsmasq profiles and several abstractions
    (including boo#911001)
  - see http://wiki.apparmor.net/index.php/ReleaseNotes_2_9_2 for the
    full changelog
- remove upstream(ed) patches apparmor-changes-since-2.9.1.diff and
  apparmor-fix-stl-ostream.diff
- replace GPG key with new AppArmor GPG signing key, see
  https://launchpad.net/apparmor/+announcement/13404
* Fri Apr 17 2015 opensuse@cboltz.de
- make sure %%service_del_postun doesn't call systemctl try-restart
  (boo#853019, bare systemd edition)
- add samba-4.2-profiles.diff: update samba (winbindd and nmb)
  profiles for samba 4.2 (boo#921098, boo#923201)
* Sun Apr 12 2015 opensuse@cboltz.de
- only install apparmor.service for openSUSE > 13.2
* Wed Apr  1 2015 crrodriguez@opensuse.org
- Add a native systemd unit which *at the moment* only
  wraps/masks the early boot script.
* Tue Feb 24 2015 rguenther@suse.com
- add apparmor-fix-stl-ostream.diff which fixes odd uses of
  std::ostream which are not valid.  Fixes build with GCC 5
* Fri Feb 20 2015 opensuse@cboltz.de
- allow lessopen.sh to run /usr/bin/unzip-plain (boo#906858)
* Thu Feb 12 2015 opensuse@cboltz.de
- add Requires: python3 to python3-apparmor package - readline isn't
  part of python3-base (boo#917577)
* Tue Jan 20 2015 opensuse@cboltz.de
- add apparmor-changes-since-2.9.1.diff with upstream fixes since the
  2.9.1 release
  - update logparser.py to support changed syslog format (lp#1399027)
  - update usr.sbin.dovecot and usr.lib.dovecot.imap{, -login} profiles
    (lp#1296667)
  - update the mysqld profile
  - fix network rule description in apparmor.d(5) manpage
- drop upstreamed dnsmasq-profile-fixes.patch
- update expired GPG key
* Thu Jan  1 2015 opensuse@cboltz.de
- update to AppArmor 2.9.1 (2.9 branch r2831)
  - fix log parsing for 3.16 kernels and syslog-style logs (boo#905368)
  - several fixes and performance improvements in the aa-* utils
  - profile updates for dnsmasq (boo#907870), nscd (boo#904620#c14 and
    bnc#908856), useradd, sendmail, man and passwd
  - see http://wiki.apparmor.net/index.php/ReleaseNotes_2_9_1
    for full release notes
- refresh dnsmasq-profile-fixes.patch
* Mon Dec 22 2014 cbosdonnat@suse.com
- Fix dnsmasq profile to allow executing bash to run the --dhcp-script
  argument. Also fixed /usr/lib -> /usr/{lib,lib64} to get libvirt
  leasehealper script to run even on x86_64.
  dnsmasq-profile-fixes.patch. boo#911001
* Sun Dec 21 2014 opensuse@cboltz.de
- rename lessopen.sh profile file to usr.bin.lessopen.sh to match the
  script filename
* Wed Dec 10 2014 meissner@suse.com
- add apparmor-lessopen-profile.patch: /usr/bin/lessopen.sh needs
  confinement. bnc#906858
* Sun Nov 16 2014 opensuse@cboltz.de
- delete cache in apparmor-profiles %%post (workaround for
  bnc#904620#c8 / lp#1392042)
* Fri Nov 14 2014 dimstar@opensuse.org
- No longer perform gpg validation; osc source_validator does it
  implicit:
  + Drop gpg-offline BuildRequires.
  + No longer execute gpg_verify.
* Sun Nov  9 2014 Led <ledest@gmail.com>
- fix bashism in post script
* Sat Oct 18 2014 opensuse@cboltz.de
- update to AppArmor 2.9.0 (r2759)
  - change aa-mergeprof to the final commandline syntax
  - lots of bugfixes in the aa-* tools (bnc#900163, lp#1328707 and several
    bugs without a formal bugreport)
  - small additions to gnome, freedesktop.org, ubuntu-browsers.d/java
    and user-mail abstractions
  - fix mod_apparmor to not break basic auth
  - update perl modules to support signal, unix and ptrace rules (bnc#900013)
  - don't warn about rules not supported by the kernel
  - fix logging of "audit capability" (lp#1378091)
  - add support for the "hat" keyword in apparmor.vim
  - build html version of apparmor.vim manpage again (lp#1366572)
  - see also http://wiki.apparmor.net/index.php/ReleaseNotes_2_9_0
- update apparmor-abstractions-no-multiline.diff
- remove upstreamed apparmor-profiles-ntpd-pid-location.diff
* Fri Oct 10 2014 opensuse@cboltz.de
- add apparmor-abstractions-no-multiline.diff: change all multiline
  rules into one line. Needed for yast2-apparmor (bnc#900013)
* Mon Oct  6 2014 opensuse@cboltz.de
- add apparmor-profiles-ntpd-pid-location.diff to cover new ntpd pid
  location (bnc#899746)
* Sun Oct  5 2014 opensuse@cboltz.de
- update to AppArmor 2.8.97 (aka 2.9 beta3 aka r2721)
  - several bugfixes in python and C tools
  - rename "__unused" to "unused" in apparmor_parser to fix compilation
    on openSUSE <= 13.1 x86_64 (bnc#895495)
  - usr.lib.dovecot.auth profile: allow access to auth-token-secret.dat
  - various small profile improvements
  - update and add several testcases
- drop upstreamed patch apparmor-profiles-dnsmasq-iface-mtu.patch
- re-number remaining patches
* Sun Sep 28 2014 opensuse@cboltz.de
- split apparmor-profiles package into -profiles and -abstractions
* Sat Sep  6 2014 opensuse@cboltz.de
- update to AppArmor 2.8.96 (aka 2.9 beta2 aka r2652)
  - add unix abstract sockets, ptrace, and signal policy generation
  - several bugfixes in the python tools and elsewhere
  - move program-chunks/postfix-common to abstractions/
  - drop upstreamed patches:
  - apparmor-profiles-clustered-samba.diff
  - perl-apparmor-fix-bare-network-keyword-handling.diff
  - perl-apparmor-handle-bare-capability-keyword.diff
  - perl-apparmor-properly-handle-bare-file-keyword.diff
- re-enable installation of perl modules
- move python modules to python3-apparmor package
- create symlinks without aa- prefix only for tools existing in 2.8.x,
  but not for new tools added in 2.9
- make utils filelist explicit to ensure we have the right set of files
  without aa- prefix in sbindir
- switch easyprof python module location to python3
- drop unused defines APPARMOR_DOC_DIR and JNI_SO
- refresh patches:
  - apparmor-utils-string-split (file moved)
  - apparmor-profiles-dnsmasq-iface-mtu.patch
  - apparmor-2.5.1-edirectory-profile
* Fri Sep  5 2014 opensuse@cboltz.de
  (prepared Thu Mar 20 23:35:03 UTC 2014 in home project)
- update to AppArmor 2.8.95 (aka 2.9 beta1)
  - complete rewrite of the aa-* tools in python
  - new tools: aa-cleanprof, aa-mergeprof
  - extra profiles moved to /usr/share/apparmor/extra-profiles/ (bnc#713647)
  - and much more, but there's no upstream changelog yet
- drop upstreamed patches and files:
  - usr.sbin.winbindd
  - usr.lib.dovecot.*, tunables-dovecot, apparmor-profiles-dovecot-bnc851984.diff
  - apparmor-init.py-gsoc.diff
  - apparmor-2.8.2-nm-dnsmasq-config.patch
- add %%bcond_with perl and disable the perl subpackage temporarily (the perl
  modules will be back in beta2)
- drop the apparmorapplet-gnome, apparmor-dbus and profile-editor subpackages
  (they were disabled since a long time, and upstream no longer ships their code)
  and the apparmor-profile-editor.desktop and apparmor-profile-editor.png files
- drop apparmor-utils-subdomain-compat patch (was only included for <= 12.1)
- remove libimmunix Provides/Obsoletes (libimmunix was a compat wrapper
  and got finally dropped)
- refresh apparmor-samba-include-permissions-for-shares.diff and
  apparmor-2.5.1-edirectory-profile
* Thu Sep  4 2014 jfehlig@suse.com
- add apparmor-profiles-dnsmasq-iface-mtu.patch to allow dnsmasq
  read access to interface mtu in
  /proc/sys/net/ipv6/conf/<ifacename>/mtu
  (bnc#892374)
* Mon Aug 11 2014 opensuse@cboltz.de
- usr.lib.dovecot.auth: add '/etc/dovecot/* r' to allow reading
  plaintext password files (bnc#874094)
* Thu Jul 31 2014 dimstar@opensuse.org
- Rename rpmlintrc to %%{name}-rpmlintrc.
  Follow the packaging guidelines.
* Wed Jul 30 2014 jeffm@suse.com
- add perl-apparmor-fix-bare-network-keyword-handling.diff:
  perl-apparmor: Fix handling of network (or network all) (bnc#889650)
- add perl-apparmor-handle-bare-capability-keyword.diff:
  perl-apparmor: Fix handling of capability keyword (bnc#889651)
- add perl-apparmor-properly-handle-bare-file-keyword.diff:
  perl-apparmor: Properly handle bare file keyword (bnc#889652)
* Thu Jul  3 2014 ddiss@suse.com
- add apparmor-profiles-clustered-samba.diff to permit clustered Samba
  access to CTDB socket and databases (bnc#885317)
* Wed Jul  2 2014 chris@computersalat.de
- fix problems with dovecot and managesieve
  * usr.lib.dovecot.managesieve-login: network inet6 stream
  * usr.lib.dovecot.managesieve:
    +#include <tunables/dovecot>
    /usr/lib/dovecot/managesieve {
    [#]include <abstractions/base>
    +  capability setgid,
    +  capability setuid,
    +  network inet stream,
    +  network inet6 stream,
    +  @{DOVECOT_MAILSTORE}/ rw,
    +  @{DOVECOT_MAILSTORE}/** rwkl,
* Fri Jun 27 2014 chris@computersalat.de
- add #include <abstractions/wutmp> to usr.lib.dovecot.auth
* Tue Apr  1 2014 lmuelle@suse.com
- update usr.sbin.winbindd profile (bnc#870607)
  - restrict rw access to /var/cache/krb5rcache/ instead /var/tmp/
* Fri Mar 28 2014 lmuelle@suse.com
- update usr.sbin.winbindd profile (bnc#870607)
  - treat passdb.tdb.tmp as passdb.tdb
  - allow rw access to /var/tmp/
* Thu Mar 20 2014 opensuse@cboltz.de
- add Recommends: libnotify-tools to apparmor-utils (aa-notify -p
  needs notify-send)
* Mon Feb 17 2014 opensuse@cboltz.de
- update to AppArmor 2.8.3 (r2122) bugfix release
  - fix some cache clearing bugs in apparmor_parser
  - various fixes in mod_apparmor
  - several profile updates, most of them were already included as patches
    (except abstractions/winbind (bnc#863226), abstractions/fonts and
    abstractions/p11-kit)
  - see http://wiki.apparmor.net/index.php/ReleaseNotes_2_8_3 for all details
- update partially upstreamed apparmor-2.8.2-nm-dnsmasq-config.patch
- remove upstream(ed) patches
  - apparmor-2.8.2-fix-ntpd-profile.diff
  - apparmor-abstractions-r2089-r2090.diff
  - apparmor-abstractions-ssl_certs.diff
  - apparmor-fix-url-in-manpages-r2093.diff
  - apparmor-no-perl-smartmatch-r2088.diff
  - apparmor-profiles-dnsmasq.diff
  - apparmor-profiles-ntpd-r2103.diff
  - apparmor-profiles-samba-create-dirs.diff
  - apparmor-profiles-samba4.diff
  - apparmor-unconfined-lang-r2094.diff
  - apparmor-utils-po-de-r2091.diff
* Sat Feb  1 2014 coolo@suse.com
- use current ruby macros, the rb_sitearch is obsolete since at least
  12.1
* Sun Jan 26 2014 opensuse@cboltz.de
- update apparmor-2.8.2-nm-dnsmasq-config.patch - allow access to pid file
  and supplemental config directory (by develop7)
- update apparmor-profiles-dovecot-bnc851984.diff:
  - do not add access to @{DOVECOT_MAILSTORE} - not required by the main binary
  - add abstractions/mysql
  - allow execution of some more /usr/lib/dovecot/* binaries
  - better restrict access to /var/spool/postfix/private/
- update usr.lib.dovecot.auth to allow to read mysql config files
- update usr.lib.dovecot.dict and usr.lib.dovecot.lmtp:
  add abstractions/nameservice instead of allowing more and more files
* Sun Jan 19 2014 opensuse@cboltz.de
- add Recommends: net-tools to apparmor-utils (needed by aa-unconfined)
- update usr.lib.dovecot.lmtp (add /proc/*/mounts, /tmp/dovecot.lmtp.*,
  /{var/,}run/dovecot/mounts, deny capability block_suspend)
* Fri Jan 17 2014 develop7@develop7.info
- add apparmor-2.8.2-nm-dnsmasq-config.patch - allow dnsmasq read config
  created by recent NetworkManager (see
  http://cgit.freedesktop.org/NetworkManager/NetworkManager/commit/?id=d82669d3fdaa7ec70ef1b64941c101ac810c394b
  for update details)
* Sat Jan  4 2014 opensuse@cboltz.de
- add apparmor-profiles-samba-create-dirs.diff to allow samba to
  mkdir /var/run/samba and /var/cache/samba (bnc#856651)
- add abstractions/samba to usr.sbin.winbindd profile
- add capabilities ipc_lock and setuid to usr.sbin.winbindd profile (bnc#851131)
- update dovecot profiles to support dovecot 2.x, and add profiles for
  the parts of dovecot that were not covered yet (bnc#851984)
  NOTE: Please adjust /etc/apparmor.d/tunables/dovecot to your needs.
  (apparmor-profiles-dovecot-bnc851984.diff, usr.lib.dovecot.*)
- %%restart_on_update (in parser %%postun) is "translated" to stop/start by
  the systemd wrapper, which removes AppArmor protection from running
  processes. Fixed by using a custom script instead (bnc#853019)
  NOTE: The %%postun from the previously installed apparmor-parser package
  will remove AppArmor protection from running processes a last time.
  Run aa-status to get a list of processes you need to restart, or reboot
  your computer.
- reload profiles in %%post of the apparmor-profiles package
* Mon Nov 25 2013 opensuse@cboltz.de
- add apparmor-abstractions-ssl_certs.diff to allow access to
  certificates in /var/lib/ca-certificates/ (bnc#852018)
* Thu Nov 14 2013 opensuse@cboltz.de
- add apparmor-profiles-ntpd-r2103.diff with updated driftfile
  location for ntpd (bnc#850374)
* Sat Nov  2 2013 opensuse@cboltz.de
- apparmor-profiles-samba4.diff, usr.sbin.winbindd: some more profile
  updates for samba 4.x and kerberos (bnc#846586#c12 and #c15)
* Wed Oct 30 2013 opensuse@cboltz.de
- add apparmor-profiles-dnsmasq.diff - add missing permissions for
  libvirt-generated files to dnsmasq profile (bnc#848215)
* Sun Oct 20 2013 opensuse@cboltz.de
- apparmor-profiles-samba4.diff, usr.sbin.winbindd: some more profile
  updates for samba 4.x (bnc#846054#c5)
* Tue Oct 15 2013 opensuse@cboltz.de
- add apparmor-profiles-samba4.diff - various profile additions for
  samba 4.x (bnc#845867, bnc#846054)
- update usr.sbin.winbindd for samba 4.x (bnc#845867, bnc#846054)
* Sun Sep 29 2013 opensuse@cboltz.de
- update apparmor-init.py-gsoc.diff to the final GSoC apparmor/__init__.py
* Fri Sep 20 2013 opensuse@cboltz.de
- add apparmor-fix-url-in-manpages-r2093.diff: fix URL in manpages
- add apparmor-unconfined-lang-r2094.diff: fix aa-unconfined to work
  in all languages
* Mon Sep 16 2013 seife+obs@b1-systems.com
- fix ntp by allowing read access to openssl.cnf
* Fri Sep 13 2013 opensuse@cboltz.de
- add apparmor-utils-po-de-r2091.diff: fix some (mis)translations
* Thu Sep 12 2013 opensuse@cboltz.de
- add apparmor-abstractions-r2089-r2090.diff (from upstream 2.8 branch)
  - p11-kit needs access to /usr/share/p11-kit/modules
  - allow reading /etc/machine-id in the dbus-session abstraction
- add apparmor-init.py-gsoc.diff - make apparmor/__init__.py ready for
  the new tools developed in GSoC
* Fri Aug 23 2013 opensuse@cboltz.de
- add apparmor-no-perl-smartmatch-r2088.diff: ~~ was marked as experimental
  in perl 5.18 again - use grep instead (upstream 2.8 branch r2088)
- fix ruby requires
* Fri Aug 16 2013 opensuse@cboltz.de
- update to AppArmor 2.8.2
  - several fixes for python3 compability
  - various profile improvements:
  - various additions to abstractions/fonts
  - move poppler's cMaps from gnome to fonts; gnome includes fonts
  - deny @{HOME}/.gnome2/keyrings/** to abstractions/private-files-strict
  - add read access to @{PROC}/sys/vm/overcommit_memory to abstractions/base
    (bnc#824577)
  - update pulseaudio directory and cookie file paths
  - add missing permissions to the nscd profile (bnc#807104)
  - deny capability block_suspend to nscd (bnc#807104)
  - MariaDB compatability in abstractions/mysql (bnc#798183)
  - see http://wiki.apparmor.net/index.php/ReleaseNotes_2_8_2 for all details
- removed upstream(ed) patches
  - apparmor-abstractions-mysql-path.diff
  - apparmor-profiles-nscd.diff
  - apparmor-python3-r2052.diff
* Thu Aug 15 2013 opensuse@cboltz.de
- swig for python3 is broken on openSUSE 12.2 - build python-apparmor
  (for python2) instead on 12.2
* Thu Aug 15 2013 opensuse@cboltz.de
- add python3-apparmor subpackage (currently py2 OR py3 package can be
  build, but not both at the same time)
- add upstream apparmor-python3-r2052.diff to fix various python3 issues
* Tue Jun  4 2013 kkaempf@suse.com
- Ruby 2.0 mkmf gets the path to ruby.h wrong (bnc#822277)
* Mon May 13 2013 coolo@suse.com
- do not package directories as %%config - especially not as noreplace
* Tue Apr 23 2013 opensuse@cboltz.de
- enable python and ruby subpackages (using %%bcond_without)
- update/fix paths in %%files for python and ruby subpackages
* Tue Apr  2 2013 opensuse@cboltz.de
- add Requires: insserv to parser package (needed by initscript)
* Tue Mar  5 2013 opensuse@cboltz.de
- nscd profile: add missing permissions and deny capability block_suspend
  (bnc#807104, apparmor-profiles-nscd.diff)
* Sun Feb 17 2013 jengelh@inai.de
- Add missing files to SRPM (bnc#777471)
* Sun Jan 13 2013 opensuse@cboltz.de
- update abstractions/mysql with correct paths and add MariaDB paths
  (bnc#798183)
* Thu Jan 10 2013 opensuse@cboltz.de
- update to AppArmor 2.8.1 (=2.8 branch r2069)
  Bugfix release, http://wiki.apparmor.net/index.php/ReleaseNotes_2_8_1
  Most important changes are:
  - add various missing parts to profiles and abstractions
  - fix a possible x conflict with hats or child profiles in
    apparmor_parser
  - fix and speedup stdin handling in aa-decode
  - various other bugfixes
  - add pkgconfig support to libapparmor
- remove upstream(ed) patches
* Mon Dec  3 2012 opensuse@cboltz.de
- verify tarball with gpg-offline
* Tue Sep 25 2012 coolo@suse.com
- fix directory flags for /etc/apparmor.d to be in sync between
  - parser and -profiles subpackage
* Fri Sep 21 2012 opensuse@cboltz.de
- remove %%stop_on_removal for no longer existing aaeventd (bnc#781564)
- don't hide TeX output when building the parser and techdoc
* Thu Aug  9 2012 opensuse@cboltz.de
- clear and update inconsistent profile cache (bnc#774529)
* Sun Aug  5 2012 opensuse@cboltz.de
- abstractions/bash: update /bin/ls to also match /usr/bin/ls (usrMerge)
* Mon Jul 30 2012 werner@suse.de
- Add required fonts for new TeXLive 2012
* Fri Jul  6 2012 opensuse@cboltz.de
- update /bin/ping profile to also match /usr/bin/ping (usrMerge)
* Sat Jun  2 2012 opensuse@cboltz.de
- update to AppArmor 2.8.0 (= r2047)
  - new utility aa-easyprof - templated profile generation tool (the resulting
    profile may be less strict than profiles generated with genprof/logprof)
  - various small bugfixes
- removed upstreamed patches
* Tue May  8 2012 opensuse@cboltz.de
- add apparmor-techdoc.patch to remove traces of the build time in PDF files
* Sat May  5 2012 opensuse@cboltz.de
- update to AppArmor 2.8 beta5 (= 2.7.103 / r2031)
  - new utility aa-exec to confine a program with the specified AppArmor profile
  - add support for mount rules
  - see http://wiki.apparmor.net/index.php/ReleaseNotes_2_8 for full upstream
    changelog
- removed upstreamed and backported patches
- remove outdated autobuild and "disable repo" patches that were disabled since
  the AppArmor 2.7 package
- create the Immunix::SubDomain compat perl module only for openSUSE <= 12.1
  (bnc#720617 #c7)
* Mon Apr 16 2012 opensuse@cboltz.de
- replace patch for dnsmasq profile with upstream patch (bnc#738905)
* Fri Apr 13 2012 opensuse@cboltz.de
- add apparmor-r2022-log-parser-network-bnc755923.patch - logprof didn't
  create network rules because of changed log format (bnc#755923, lp#800826)
- add profile for samba winbindd (bnc#748499)
* Fri Apr  6 2012 mszeredi@suse.cz
- fix dnsmasq profile (bnc#738905)
* Thu Feb  9 2012 opensuse@cboltz.de
- add 0001-fix-for-lp929531.patch to allow reading
  /sys/devices/system/cpu/online in abstractions/base (lp#929531)
* Tue Jan 31 2012 opensuse@cboltz.de
- Update to AppArmor 2.7.2 (= 2.7 branch / r1894)
  - move various permissions from httpd2-prefork profile to
    abstractions/apache2-common. Backward-incompatible change: *.htaccess
    files are no longer allowed for ^HANDLING_UNTRUSTED_INPUT
  - allow access for more /usr/lib*/samba/ files for smbd (bnc#725967#c5)
  - allow various .conf files for dovecot (lp#458922)
  - disallow wl for *.so in @{HOME}/.pki/nssdb/ in abstractions/private-files
    and abstractions/private-files-strict (lp#911847)
  - update abstractions/kde, private-files* and ubuntu-browsers.d/user-files
    to use ~/.kde4, not only ~/.kde (bnc#741592)
  - block write access to ~/.kde{,4}/env in abstractions/private-files
    (lp#914190)
  - allow write access for personal dictionary etc. in abstractions/aspell
    (lp#917859)
  - when using genprof for a script, include read access to the script itsself
  - automatically include abstractions/python or abstractions/ruby for
    python/ruby scripts
  - add profile for smbldap-useradd and allow smbd to call it (bnc#738041)
  - allow creation of the .config directory in abstractions/enchant (lp#914184)
  - allow TFTP read-only access in dnsmasq profile (lp#905412)
  - allow capability dac_read_search for syslog-ng (bnc#731876)
  - add p11-kit abstraction and include it in abstractions/authentification
    (lp#912754, lp#912752)
  - add audacity to abstractions/ubuntu-media-players (lp#899963)
  - allow software-center, fireclam plugin, [tT]unar, exo-open, kate and
    /dev/nvidia* in abstractons/ubuntu-browsers.d/* (lp#662906, lp#562831,
    lp#890894, lp#890894, lp#884748)
  - fix typo for multiarch gconf-modules in abstractions/base (lp#904548)
  - allow avahi to do dbus introspection (lp#769148)
  - allow access to ~/.fonts.conf.d in abstractions/fonts (lp#870992)
  - allow transmission in abstractions/ubuntu-bittorrent-clients (lp#852062)
  - allow reading ~/.cups/client.conf and ~/.cups/lpoptions in
    abstractions/cups-client (lp#887992)
  - allow read access of /etc/python{2,3}.[0-7]*/sitecustomize.py in
    abstractions/python (lp#860856)
  - various updates to the sshd profile (lp#817956)
  - (and some more changes I already included in the apparmor-2.7-branch.diff)
* Tue Jan  3 2012 opensuse@cboltz.de
- Update to AppArmor 2.7.0 (= r1858)
  - make traceroute6 work (bnc#733312)
  - allow access to pyconfig.h in abstractions/python (lp#840734)
  - fix logprof/genprof for hex-encoded program filenames (= filenames
    containing space etc.)
- add apparmor-2.7-branch.diff with some upstreamed fixes:
  - usr.sbin.smbd needs read access for /etc/netgroup (bnc#738041)
  - create /etc/apparmor.d/tunables/multiarch.d as directory, not as file
  - fix syntax error in abstractons/python
* Tue Nov 29 2011 meissner@suse.de
- changed a $ -> %% (typo)
* Sat Nov 26 2011 opensuse@cboltz.de
- package subdomain.conf only in -parser, not in -utils package
- package libapparmor.so and libimmunix.so only in libapparmor-devel,
  not in libapparmor1
- make Provides for perl-libapparmor versioned to avoid self-Obsoletes
- move libapparmor.a and libimmunix.a from libapparmor1 to
  libapparmor-devel package
* Thu Nov 10 2011 opensuse@cboltz.de
- update to AppArmor 2.7.0 rc2
  Most of the changes since rc1 were already included as patches.
  Additional changes:
  - fix logprof/genprof to recognize "mknod" in audit.log
  - fix libapparmor python bindings to compile with python 3
  - fix wrong status message in initscript if apparmor-utils are not installed
  - parser/Makefile: fix some warnings, always respect CXX and LDFLAGS
  - fix some warnings in utils/Makefile
- remove 4 upstreamed patches
- remove mkdir /etc/apparmor.d/disable - that's done by upstream Makefile now
- update line numbers in 2 patches
* Tue Nov  1 2011 opensuse@cboltz.de
- make abstractions/winbind working on 64bit systems
- allow loading the libraries for samba "vfs objects" also on 32bit
  systems (bnc#725967)
* Wed Oct 26 2011 opensuse@cboltz.de
- allow loading the libraries for samba "vfs objects" (bnc#725967)
* Wed Oct 19 2011 opensuse@cboltz.de
- include autogenerated profile sniplet for samba shares (bnc#688040)
- more helpful error message for "aa-notify -p" if the user is not in
  the configured group
* Thu Oct 13 2011 opensuse@cboltz.de
- update to AppArmor 2.7.0 rc1
  - aa-notify: add --display option and warn if $DISPLAY is not set
    (important for usage with sudo on openSUSE)
  - fix syntax error on "rcapparmor stop"
  - allow read access to /proc/*/mounts in the dovecot profile
* Sun Oct  9 2011 opensuse@cboltz.de
- add patch with upstream changes since 2.7.0 beta2 release
  - add example parser.conf
  - print warning if profile cache directory doesn't exist
  - remove initscript for no longer existing aa-eventd (bnc#720617)
  - set correct $HOME in aa-notify
- enable caching of profiles (= massive speedup) (bnc#689458)
- add comments for patches in .spec and comments in some patches
- run spec-cleaner
* Fri Sep 30 2011 coolo@suse.com
- add libtool as buildrequire to make the spec file more reliable
* Fri Sep 16 2011 opensuse@cboltz.de
- update to AppArmor 2.7.0 beta2
  - includes fixes for bnc#717707, bnc#678749, bnc#685674, bnc#679182,
    bnc#691072, bnc#705319, bnc#713728
- add some missing perl module Requires to perl-apparmor
* Tue Sep 13 2011 opensuse@cboltz.de
- update to AppArmor 2.7.0 beta1, for details see
  http://wiki.apparmor.net/index.php/ReleaseNotes_2_7
- removed lots of patches I pushed upstream
- disabled apparmor-2.5.1-unified-build (patch to use automake,
  does not apply to 2.7 and probably won't be accepted upstream)
- disabled build of tomcat_apparmor (doesn't build, deprecated upstream)
- run spec-cleaner
- remove *.la files
- move usr.sbin.nscd profile back to apparmor-profiles package
* Wed Sep  7 2011 jfehlig@suse.com
- Update patch apparmor-profiles-usr.sbin.dnsmasq to include
  /var/lib/libvirt/dnsmasq/*.leases (bnc#694197).
* Mon Aug 22 2011 opensuse@cboltz.de
- install SubDomain.pm compat module (bnc#713408)
* Wed Aug  3 2011 jeffm@suse.de
- Update to 2.6.1.
  - One patch eliminated
  - Lots of minor fixes
  - Split out more common abstractions
- Add check_for_apparmor() helper.
* Tue Aug  2 2011 jeffm@suse.de
- dhcpd: Fix apparmor profile (bnc#692428)
* Tue Aug  2 2011 fcrozat@suse.com
- Add apparmor-securityfs-systemd.patch: do not mount securityfs
  when running under systemd, just access the directory, systemd
  will automount it (bnc#704460).
* Sun Jul 17 2011 andrea.turrini@gmail.com
- Fixed typos in descriptions and summaries of apparmor.spec
* Fri Jun 24 2011 jeffm@suse.de
- Fixed building of pam_apparmor to properly link libpam (bnc#696553).
- Fixed building of apache2-mod_apparmor to properly link (bnc#701821).
* Tue Jun 21 2011 coolo@novell.com
- move the requires and prerequires to the right package
* Wed Apr 27 2011 opensuse@cboltz.de
- make the -doc and -profiles subpackages noarch (again)
* Thu Mar 24 2011 jeffm@suse.de
- Added alias from Immunix::SubDomain to Immunix:AppArmor to allow
  older users of perl-apparmor to work properly.
* Tue Mar 22 2011 jeffm@suse.de
- Properly re-created links to old utility names.
* Mon Mar 14 2011 jeffm@suse.de
- Added /etc/ethers and /var/run/dnsmasq-forwarders to
  usr.sbin.dnsmasq (bnc#678749)
* Mon Mar 14 2011 jeffm@suse.de
- Update to 2.6.0
  - 19 patches eliminated
  - Lots of minor fixes.
  - Split out more common abstractions
  - Added more local includes
* Tue Mar  1 2011 rhafer@suse.de
- Additional libvirt related fixes in usr.sbin.dnsmasq (bnc#675867)
* Thu Feb 24 2011 jeffm@suse.de
- Added 'network packet raw' to dhclient profile.
* Tue Feb 22 2011 bwiedemann@novell.com
- Add Requires for used perl packages (bnc#670650).
* Tue Jan 25 2011 jeffm@suse.de
- Updated dhclient profile and added dhclient-script profile (bnc#561152).
* Tue Jan 25 2011 jeffm@suse.de
- Added ability to completely disable repositories.
* Mon Jan 24 2011 jeffm@suse.de
- Properly indent sub-profiles after genprof completion (bnc#480795).
* Mon Jan 24 2011 jeffm@suse.de
- Inherit flags in sub-profiles when generating profiles (bnc#496204).
* Mon Jan 24 2011 jeffm@suse.de
- Stop treating profiles shipped with the package as config files.
  - /etc/apparmor.d will still be treated specially.
- Add support for parsing network operation events (bnc#665483)
* Sun Jan 23 2011 jeffm@suse.de
- Fix for sbin.klogd profile using kernel versions >= 2.6.38-rc1.
* Sun Jan 23 2011 jeffm@suse.de
- Update to apparmor-2.5 r1445.
  - Includes 3 of the fixes below.
  - Several testsuite fixes.
  - Update for Thunderbird profile.
* Fri Jan 21 2011 jeffm@suse.de
- Add support for libvirt in usr.sbin.dnsmasq (bnc#666090)
* Tue Jan 18 2011 coolo@novell.com
- fix rm call for nscd profile to avoid file conflict
* Tue Jan 11 2011 jeffm@suse.de
- profiles: Add openssl abstraction (bnc#623886).
* Tue Jan 11 2011 jeffm@suse.de
- Added support for sys_nice to ntpd profile (bnc#657054).
* Mon Jan 10 2011 jeffm@suse.de
- apparmor-utils: Support newer auditd formatted messages.
- Fix two x transition conflict bugs. (bnc#662928)
* Thu Jan  6 2011 rhafer@suse.de
- Splitted ldap related things from nameservice into separate
  profile and added some missing paths (bnc#662761)
* Wed Dec 22 2010 jeffm@suse.de
- Fixed pod2man macros with older versions of GNU make
* Mon Dec 20 2010 jeffm@suse.de
- Fixed building of perl and ruby SWIG modules. The former
  is required for apparmor-utils to work properly.
* Tue Dec  7 2010 jeffm@suse.de
- Fixed use-after-free issue in apparmor_parser.
* Tue Dec  7 2010 jeffm@suse.de
- Added fixes for logprof issuing uninitialized variable errors
  while encountering audit messages for unconfined processes.
* Wed Dec  1 2010 jeffm@suse.de
- Updated cupsd profile (bnc#539401)
* Wed Dec  1 2010 jeffm@suse.de
- Fix {proc} vs {PROC} macro usage in firefox profile (bnc#436262)
* Wed Dec  1 2010 jeffm@suse.de
- Added support for eDirectory nameservice (bnc#621394)
* Wed Dec  1 2010 jeffm@suse.de
- Fixed incorrect /proc/*/sys usage in usr.sbin.ntpd profile (bnc#634801)
* Wed Dec  1 2010 jeffm@suse.de
- Added fix for another case of whitespace affecting profile
  removal (bnc#510740)
* Tue Nov 30 2010 jeffm@suse.de
- Added support for unified build, which massively simplified
  the packaging.
* Mon Nov 15 2010 czanik@balabit.hu
- Fix for syslog-ng profile to allow upgrade to v3.2
- add mysql support to syslog-ng profile
* Thu Oct 21 2010 jeffm@suse.de
- Added support for enabling/disabling the module automatically
  during installation/removal (bnc#623246)
* Tue Oct  5 2010 jeffm@suse.de
- Converted archive to tar.bz2.
* Tue Oct  5 2010 jeffm@suse.de
- Updated to 2.5.1-final.
  - Lots of testcase updates.
* Fri Aug 27 2010 jeffm@suse.de
- Initial packaging of AppArmor 2.5
  - Now contained in a single archive so built from a single spec file
